@@ -5,7 +5,7 @@
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- *       http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -19,26 +19,33 @@ package org.drools.workbench.screens.guided.dtable.client.editor;
 import java.util.List;
 import java.util.Optional;
 import java.util.Set;
+
 import javax.enterprise.event.Event;
+import javax.enterprise.event.Observes;
 
 import com.google.gwt.user.client.ui.IsWidget;
 import com.google.gwt.user.client.ui.ProvidesResize;
 import com.google.gwt.user.client.ui.RequiresResize;
+import elemental2.dom.HTMLElement;
 import org.drools.workbench.models.guided.dtable.shared.model.GuidedDecisionTable52;
 import org.drools.workbench.screens.guided.dtable.client.editor.menu.EditMenuBuilder;
 import org.drools.workbench.screens.guided.dtable.client.editor.menu.InsertMenuBuilder;
 import org.drools.workbench.screens.guided.dtable.client.editor.menu.RadarMenuBuilder;
 import org.drools.workbench.screens.guided.dtable.client.editor.menu.ViewMenuBuilder;
+import org.drools.workbench.screens.guided.dtable.client.editor.page.ColumnsPage;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.GuidedDecisionTableModellerView;
+import org.drools.workbench.screens.guided.dtable.client.widget.table.GuidedDecisionTablePresenter;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.GuidedDecisionTableView;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.events.cdi.DecisionTableSelectedEvent;
 import org.drools.workbench.screens.guided.dtable.model.GuidedDecisionTableEditorContent;
 import org.drools.workbench.screens.guided.dtable.service.GuidedDecisionTableEditorService;
-import org.guvnor.common.services.project.context.ProjectContext;
+import org.guvnor.common.services.project.client.context.WorkspaceProjectContext;
 import org.guvnor.common.services.shared.metadata.model.Metadata;
 import org.guvnor.common.services.shared.validation.model.ValidationMessage;
+import org.guvnor.messageconsole.client.console.widget.button.AlertsButtonMenuItemBuilder;
 import org.jboss.errai.common.client.api.Caller;
 import org.jboss.errai.common.client.api.RemoteCallback;
+import org.jboss.errai.common.client.ui.ElementWrapperWidget;
 import org.jboss.errai.ioc.client.container.SyncBeanManager;
 import org.kie.workbench.common.widgets.client.menu.FileMenuBuilder;
 import org.kie.workbench.common.widgets.client.popups.validation.ValidationPopup;
@@ -48,17 +55,26 @@ import org.kie.workbench.common.widgets.metadata.client.KieEditorView;
 import org.kie.workbench.common.widgets.metadata.client.KieMultipleDocumentEditor;
 import org.kie.workbench.common.widgets.metadata.client.KieMultipleDocumentEditorWrapperView;
 import org.kie.workbench.common.widgets.metadata.client.menu.RegisteredDocumentsMenuBuilder;
+import org.kie.workbench.common.widgets.metadata.client.validation.AssetUpdateValidator;
 import org.kie.workbench.common.widgets.metadata.client.widget.OverviewWidgetPresenter;
+import org.kie.workbench.common.workbench.client.docks.AuthoringWorkbenchDocks;
 import org.uberfire.backend.vfs.ObservablePath;
+import org.uberfire.client.mvp.PerspectiveManager;
 import org.uberfire.client.mvp.PlaceManager;
+import org.uberfire.client.mvp.UpdatedLockStatusEvent;
 import org.uberfire.client.workbench.events.ChangeTitleWidgetEvent;
+import org.uberfire.client.workbench.events.PlaceHiddenEvent;
 import org.uberfire.client.workbench.type.ClientResourceType;
+import org.uberfire.client.workbench.widgets.multipage.MultiPageEditor;
+import org.uberfire.client.workbench.widgets.multipage.Page;
 import org.uberfire.ext.editor.commons.client.file.popups.SavePopUpPresenter;
 import org.uberfire.ext.editor.commons.client.history.VersionRecordManager;
+import org.uberfire.ext.editor.commons.client.menu.DownloadMenuItemBuilder;
 import org.uberfire.ext.editor.commons.client.menu.MenuItems;
 import org.uberfire.ext.editor.commons.client.validation.DefaultFileNameValidator;
 import org.uberfire.ext.widgets.common.client.callbacks.HasBusyIndicatorDefaultErrorCallback;
 import org.uberfire.mvp.PlaceRequest;
+import org.uberfire.mvp.impl.DefaultPlaceRequest;
 import org.uberfire.workbench.events.NotificationEvent;
 import org.uberfire.workbench.model.menu.MenuItem;
 
@@ -67,17 +83,10 @@ import org.uberfire.workbench.model.menu.MenuItem;
  */
 public abstract class BaseGuidedDecisionTableEditorPresenter extends KieMultipleDocumentEditor<GuidedDecisionTableView.Presenter> {
 
-    public interface View extends RequiresResize,
-                                  ProvidesResize,
-                                  KieEditorView,
-                                  IsWidget {
-
-        void setModellerView(final GuidedDecisionTableModellerView view);
-    }
+    static final int COLUMNS_TAB_INDEX = 1;
 
     protected View view;
     protected Caller<GuidedDecisionTableEditorService> service;
-    protected Event<NotificationEvent> notification;
     protected Event<DecisionTableSelectedEvent> decisionTableSelectedEvent;
     protected ValidationPopup validationPopup;
     protected ClientResourceType resourceType;
@@ -97,9 +106,15 @@ public abstract class BaseGuidedDecisionTableEditorPresenter extends KieMultiple
 
     protected SyncBeanManager beanManager;
     protected PlaceManager placeManager;
+    protected AlertsButtonMenuItemBuilder alertsButtonMenuItemBuilder;
+    protected PerspectiveManager perspectiveManager;
+    private ColumnsPage columnsPage;
+    private AuthoringWorkbenchDocks docks;
 
     public BaseGuidedDecisionTableEditorPresenter(final View view,
                                                   final Caller<GuidedDecisionTableEditorService> service,
+                                                  final AuthoringWorkbenchDocks docks,
+                                                  final PerspectiveManager perspectiveManager,
                                                   final Event<NotificationEvent> notification,
                                                   final Event<DecisionTableSelectedEvent> decisionTableSelectedEvent,
                                                   final ValidationPopup validationPopup,
@@ -110,10 +125,15 @@ public abstract class BaseGuidedDecisionTableEditorPresenter extends KieMultiple
                                                   final RadarMenuBuilder radarMenuBuilder,
                                                   final GuidedDecisionTableModellerView.Presenter modeller,
                                                   final SyncBeanManager beanManager,
-                                                  final PlaceManager placeManager) {
+                                                  final PlaceManager placeManager,
+                                                  final ColumnsPage columnsPage,
+                                                  final AlertsButtonMenuItemBuilder alertsButtonMenuItemBuilder,
+                                                  final DownloadMenuItemBuilder downloadMenuItemBuilder) {
         super(view);
         this.view = view;
         this.service = service;
+        this.docks = docks;
+        this.perspectiveManager = perspectiveManager;
         this.notification = notification;
         this.decisionTableSelectedEvent = decisionTableSelectedEvent;
         this.validationPopup = validationPopup;
@@ -125,6 +145,9 @@ public abstract class BaseGuidedDecisionTableEditorPresenter extends KieMultiple
         this.modeller = modeller;
         this.beanManager = beanManager;
         this.placeManager = placeManager;
+        this.columnsPage = columnsPage;
+        this.alertsButtonMenuItemBuilder = alertsButtonMenuItemBuilder;
+        this.downloadMenuItemBuilder = downloadMenuItemBuilder;
     }
 
     @Override
@@ -171,7 +194,7 @@ public abstract class BaseGuidedDecisionTableEditorPresenter extends KieMultiple
 
     @Override
     //Delegated to expose package-protected setter for Unit Tests
-    protected void setWorkbenchContext(final ProjectContext workbenchContext) {
+    protected void setWorkbenchContext(final WorkspaceProjectContext workbenchContext) {
         super.setWorkbenchContext(workbenchContext);
     }
 
@@ -199,11 +222,21 @@ public abstract class BaseGuidedDecisionTableEditorPresenter extends KieMultiple
         super.setFileNameValidator(fileNameValidator);
     }
 
+    @Override
+    //Delegated to expose package-protected setter for Unit Tests
+    protected void setAssetUpdateValidator(final AssetUpdateValidator assetUpdateValidator) {
+        super.setAssetUpdateValidator(assetUpdateValidator);
+    }
+
     protected void init() {
         viewMenuBuilder.setModeller(modeller);
         insertMenuBuilder.setModeller(modeller);
         radarMenuBuilder.setModeller(modeller);
-        view.setModellerView(modeller.getView());
+        view.setModellerView(getModellerView());
+    }
+
+    protected GuidedDecisionTableModellerView getModellerView() {
+        return modeller.getView();
     }
 
     protected void onStartup(final ObservablePath path,
@@ -213,10 +246,21 @@ public abstract class BaseGuidedDecisionTableEditorPresenter extends KieMultiple
     }
 
     protected void onFocus() {
-        if (modeller.getActiveDecisionTable() != null) {
-            decisionTableSelectedEvent.fire(new DecisionTableSelectedEvent(modeller.getActiveDecisionTable()));
-            modeller.getActiveDecisionTable().initialiseAnalysis();
+
+        if (!docks.isSetup()) {
+            docks.setup(perspectiveManager.getCurrentPerspective().getIdentifier(),
+                        new DefaultPlaceRequest("org.kie.guvnor.explorer"));
         }
+        docks.show();
+
+        modeller.getActiveDecisionTable().ifPresent(dt -> {
+            decisionTableSelectedEvent.fire(new DecisionTableSelectedEvent(dt));
+            dt.initialiseAnalysis();
+        });
+    }
+
+    private void hideDataModellerDocks(@Observes PlaceHiddenEvent event) {
+        docks.hide();
     }
 
     protected String getTitleText() {
@@ -256,6 +300,7 @@ public abstract class BaseGuidedDecisionTableEditorPresenter extends KieMultiple
                        MenuItems.VALIDATE);
 
         if (!dtPresenter.isPresent()) {
+            activeDocument = null;
             return;
         }
 
@@ -279,6 +324,78 @@ public abstract class BaseGuidedDecisionTableEditorPresenter extends KieMultiple
                          dtPresenter.getDataModelOracle(),
                          dtPresenter.getModel().getImports(),
                          !dtPresenter.getAccess().isEditable());
+
+        addColumnsTab();
+
+        enableColumnsTab(dtPresenter);
+    }
+
+    void enableColumnsTab(final GuidedDecisionTableView.Presenter decisionTablePresenter) {
+        enableColumnsTab(isGuidedDecisionTableEditable(decisionTablePresenter));
+    }
+
+    boolean isGuidedDecisionTableEditable(final GuidedDecisionTableView.Presenter decisionTablePresenter) {
+        final GuidedDecisionTablePresenter.Access access = decisionTablePresenter.getAccess();
+        final boolean decisionTableIsEditable = !access.isReadOnly();
+        final boolean decisionTableHasEditableColumns = access.hasEditableColumns();
+
+        return decisionTableIsEditable && decisionTableHasEditableColumns;
+    }
+
+    void enableColumnsTab(final boolean enabled) {
+        if (enabled) {
+            enableColumnsPage();
+        } else {
+            disableColumnsPage();
+        }
+    }
+
+    void onUpdatedLockStatusEvent(final UpdatedLockStatusEvent event) {
+        final Optional<GuidedDecisionTableView.Presenter> activeDecisionTable = modeller.getActiveDecisionTable();
+
+        if (!activeDecisionTable.isPresent()) {
+            enableColumnsTab(false);
+            return;
+        }
+
+        final boolean isEditable = isGuidedDecisionTableEditable(activeDecisionTable.get());
+        final boolean isLocked = event.isLocked() && !event.isLockedByCurrentUser();
+        final boolean enableColumnsPage = !isLocked && isEditable;
+
+        enableColumnsTab(enableColumnsPage);
+    }
+
+    void addColumnsTab() {
+
+        columnsPage.init(modeller);
+
+        addEditorPage(COLUMNS_TAB_INDEX, columnsPage);
+    }
+
+    void addEditorPage(final int index,
+                       final Page page) {
+
+        final MultiPageEditor multiPage = getKieEditorWrapperMultiPage();
+
+        multiPage.addPage(index, page);
+    }
+
+    void disableColumnsPage() {
+
+        final MultiPageEditor multiPage = getKieEditorWrapperMultiPage();
+
+        multiPage.disablePage(COLUMNS_TAB_INDEX);
+    }
+
+    void enableColumnsPage() {
+
+        final MultiPageEditor multiPage = getKieEditorWrapperMultiPage();
+
+        multiPage.enablePage(COLUMNS_TAB_INDEX);
+    }
+
+    MultiPageEditor getKieEditorWrapperMultiPage() {
+        return kieEditorWrapperView.getMultiPage();
     }
 
     @Override
@@ -318,10 +435,9 @@ public abstract class BaseGuidedDecisionTableEditorPresenter extends KieMultiple
     }
 
     void openOtherDecisionTable() {
+        decisionTableSelectedEvent.fire(DecisionTableSelectedEvent.NONE);
         final Set<GuidedDecisionTableView.Presenter> availableDecisionTables = modeller.getAvailableDecisionTables();
-        if (availableDecisionTables == null || availableDecisionTables.isEmpty()) {
-            decisionTableSelectedEvent.fire(DecisionTableSelectedEvent.NONE);
-        } else {
+        if (!(availableDecisionTables == null || availableDecisionTables.isEmpty())) {
             final GuidedDecisionTableView.Presenter dtPresenter = availableDecisionTables.iterator().next();
             decisionTableSelectedEvent.fire(new DecisionTableSelectedEvent(dtPresenter));
         }
@@ -408,6 +524,10 @@ public abstract class BaseGuidedDecisionTableEditorPresenter extends KieMultiple
         return radarMenuItem;
     }
 
+    protected ElementWrapperWidget<?> getWidget(final HTMLElement element) {
+        return ElementWrapperWidget.getWidget(element);
+    }
+
     @Override
     protected void enableMenus(final boolean enabled) {
         super.enableMenus(enabled);
@@ -416,4 +536,12 @@ public abstract class BaseGuidedDecisionTableEditorPresenter extends KieMultiple
         getInsertMenuItem().setEnabled(enabled);
         getRadarMenuItem().setEnabled(enabled);
     }
-}
\ No newline at end of file
+
+    public interface View extends RequiresResize,
+                                  ProvidesResize,
+                                  KieEditorView,
+                                  IsWidget {
+
+        void setModellerView(final GuidedDecisionTableModellerView view);
+    }
+}
