@@ -22,6 +22,7 @@ import java.util.HashSet;
 import java.util.List;
 import java.util.Optional;
 import java.util.Set;
+import java.util.function.Consumer;
 import java.util.function.Supplier;
 import java.util.stream.Collectors;
 
@@ -33,6 +34,7 @@ import javax.inject.Inject;
 
 import com.google.gwt.core.client.Scheduler;
 import com.google.gwt.user.client.ui.IsWidget;
+import elemental2.promise.Promise;
 import org.drools.workbench.models.guided.dtable.shared.model.GuidedDecisionTable52;
 import org.drools.workbench.screens.guided.dtable.client.editor.menu.EditMenuBuilder;
 import org.drools.workbench.screens.guided.dtable.client.editor.menu.InsertMenuBuilder;
@@ -52,6 +54,7 @@ import org.drools.workbench.screens.guided.dtable.model.GuidedDecisionTableEdito
 import org.drools.workbench.screens.guided.dtable.service.GuidedDecisionTableEditorService;
 import org.drools.workbench.screens.guided.dtable.service.GuidedDecisionTableGraphEditorService;
 import org.drools.workbench.screens.guided.dtable.service.GuidedDecisionTableGraphSaveAndRenameService;
+import org.guvnor.common.services.project.model.WorkspaceProject;
 import org.guvnor.common.services.shared.metadata.model.Metadata;
 import org.guvnor.common.services.shared.metadata.model.Overview;
 import org.guvnor.messageconsole.client.console.widget.button.AlertsButtonMenuItemBuilder;
@@ -82,7 +85,7 @@ import org.uberfire.client.mvp.PlaceManager;
 import org.uberfire.client.mvp.SaveInProgressEvent;
 import org.uberfire.client.mvp.UpdatedLockStatusEvent;
 import org.uberfire.client.workbench.events.ChangeTitleWidgetEvent;
-import org.uberfire.ext.editor.commons.client.menu.DownloadMenuItem;
+import org.uberfire.ext.editor.commons.client.menu.DownloadMenuItemBuilder;
 import org.uberfire.ext.editor.commons.client.menu.MenuItems;
 import org.uberfire.ext.editor.commons.client.menu.common.SaveAndRenameCommandBuilder;
 import org.uberfire.ext.editor.commons.client.resources.i18n.CommonConstants;
@@ -154,7 +157,7 @@ public class GuidedDecisionTableGraphEditorPresenter extends BaseGuidedDecisionT
                                                    final ColumnsPage columnsPage,
                                                    final SaveAndRenameCommandBuilder<List<GuidedDecisionTableEditorContent>, Metadata> saveAndRenameCommandBuilder,
                                                    final AlertsButtonMenuItemBuilder alertsButtonMenuItemBuilder,
-                                                   final DownloadMenuItem downloadMenuItem) {
+                                                   final DownloadMenuItemBuilder downloadMenuItem) {
         super(view,
               service,
               docks,
@@ -328,8 +331,8 @@ public class GuidedDecisionTableGraphEditorPresenter extends BaseGuidedDecisionT
 
     @Override
     @WorkbenchMenu
-    public Menus getMenus() {
-        return super.getMenus();
+    public void getMenus(final Consumer<Menus> menusConsumer) {
+        super.getMenus(menusConsumer);
     }
 
     @Override
@@ -392,29 +395,38 @@ public class GuidedDecisionTableGraphEditorPresenter extends BaseGuidedDecisionT
     }
 
     @Override
-    public void makeMenuBar() {
-        if (canUpdateProject()) {
-            fileMenuBuilder
-                    .addSave(getSaveMenuItem())
-                    .addCopy(versionRecordManager::getCurrentPath,
-                             assetUpdateValidator)
-                    .addRename(getSaveAndRenameCommand())
-                    .addDelete(versionRecordManager::getPathToLatest,
-                               assetUpdateValidator);
+    public Promise<Void> makeMenuBar() {
+        if (workbenchContext.getActiveWorkspaceProject().isPresent()) {
+            final WorkspaceProject activeProject = workbenchContext.getActiveWorkspaceProject().get();
+            return projectController.canUpdateProject(activeProject).then(canUpdateProject -> {
+                if (canUpdateProject) {
+                    fileMenuBuilder
+                            .addSave(getSaveMenuItem())
+                            .addCopy(versionRecordManager::getCurrentPath,
+                                     assetUpdateValidator)
+                            .addRename(getSaveAndRenameCommand())
+                            .addDelete(versionRecordManager::getPathToLatest,
+                                       assetUpdateValidator);
+                }
+
+                final FileMenuBuilder fileMenuBuilder = this.fileMenuBuilder
+                        .addValidate(() -> onValidate(getActiveDocument()))
+                        .addNewTopLevelMenu(getEditMenuItem())
+                        .addNewTopLevelMenu(getViewMenuItem())
+                        .addNewTopLevelMenu(getInsertMenuItem())
+                        .addNewTopLevelMenu(getRadarMenuItem())
+                        .addNewTopLevelMenu(getRegisteredDocumentsMenuItem())
+                        .addNewTopLevelMenu(getVersionManagerMenuItem())
+                        .addNewTopLevelMenu(alertsButtonMenuItemBuilder.build());
+                addDownloadMenuItem(fileMenuBuilder);
+
+                this.menus = fileMenuBuilder.build();
+
+                return promises.resolve();
+            });
         }
 
-        final FileMenuBuilder fileMenuBuilder = this.fileMenuBuilder
-                .addValidate(() -> onValidate(getActiveDocument()))
-                .addNewTopLevelMenu(getEditMenuItem())
-                .addNewTopLevelMenu(getViewMenuItem())
-                .addNewTopLevelMenu(getInsertMenuItem())
-                .addNewTopLevelMenu(getRadarMenuItem())
-                .addNewTopLevelMenu(getRegisteredDocumentsMenuItem())
-                .addNewTopLevelMenu(getVersionManagerMenuItem())
-                .addNewTopLevelMenu(alertsButtonMenuItemBuilder.build());
-        addDownloadMenuItem(fileMenuBuilder);
-
-        this.menus = fileMenuBuilder.build();
+        return promises.resolve();
     }
 
     protected Command getSaveAndRenameCommand() {
