@@ -1,17 +1,17 @@
 /*
  * Copyright 2015 Red Hat, Inc. and/or its affiliates.
  *
- * Licensed under the Apache License, Version 2.0 (the "License"); you may not
- * use this file except in compliance with the License. You may obtain a copy of
- * the License at
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
  *
- * http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
- * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
- * License for the specific language governing permissions and limitations under
- * the License.
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 package org.drools.workbench.screens.guided.dtable.client.widget.table.columns;
 
@@ -58,20 +58,20 @@ public class EnumSingleSelectBigDecimalUiColumn extends BaseEnumSingleSelectUiCo
     protected void initialiseMultiValueDomElement( final GridCell<BigDecimal> cell,
                                                    final GridBodyCellRenderContext context,
                                                    final Map<String, String> enumLookups ) {
-        factory.attachDomElement( context,
-                                  CallbackFactory.makeOnCreationCallback( factory,
-                                                                          cell,
-                                                                          enumLookups ),
-                                  CallbackFactory.makeOnDisplayListBoxCallback() );
+        factory.attachDomElement(context,
+                                 ConsumerFactory.makeOnCreationCallback(factory,
+                                                                        cell,
+                                                                        enumLookups ),
+                                 ConsumerFactory.makeOnDisplayListBoxCallback() );
     }
 
     @Override
     protected void initialiseSingleValueDomElement( final GridCell<BigDecimal> cell,
                                                     final GridBodyCellRenderContext context ) {
-        singleValueFactory.attachDomElement( context,
-                                             CallbackFactory.makeOnCreationCallback( singleValueFactory,
-                                                                                     cell ),
-                                             CallbackFactory.makeOnDisplayTextBoxCallback() );
+        singleValueFactory.attachDomElement(context,
+                                            ConsumerFactory.makeOnCreationCallback(singleValueFactory,
+                                                                                   cell ),
+                                            ConsumerFactory.makeOnDisplayTextBoxCallback() );
     }
 
 }
