@@ -22,6 +22,9 @@ import java.util.Optional;
 
 import javax.enterprise.event.Event;
 
+import com.google.gwt.user.client.Element;
+import com.google.gwt.user.client.ui.Widget;
+import elemental2.dom.HTMLElement;
 import org.drools.workbench.models.datamodel.workitems.PortableWorkDefinition;
 import org.drools.workbench.models.guided.dtable.shared.model.GuidedDecisionTable52;
 import org.drools.workbench.screens.guided.dtable.client.editor.menu.EditMenuBuilder;
@@ -29,6 +32,9 @@ import org.drools.workbench.screens.guided.dtable.client.editor.menu.InsertMenuB
 import org.drools.workbench.screens.guided.dtable.client.editor.menu.RadarMenuBuilder;
 import org.drools.workbench.screens.guided.dtable.client.editor.menu.ViewMenuBuilder;
 import org.drools.workbench.screens.guided.dtable.client.editor.page.ColumnsPage;
+import org.drools.workbench.screens.guided.dtable.client.editor.search.GuidedDecisionTableGridHighlightHelper;
+import org.drools.workbench.screens.guided.dtable.client.editor.search.GuidedDecisionTableSearchableElement;
+import org.drools.workbench.screens.guided.dtable.client.editor.search.SearchableElementFactory;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.GuidedDecisionTableModellerView;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.GuidedDecisionTablePresenter;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.GuidedDecisionTableView;
@@ -37,19 +43,25 @@ import org.drools.workbench.screens.guided.dtable.model.GuidedDecisionTableEdito
 import org.drools.workbench.screens.guided.dtable.service.GuidedDecisionTableEditorService;
 import org.guvnor.common.services.project.client.context.WorkspaceProjectContext;
 import org.guvnor.common.services.project.client.security.ProjectController;
+import org.guvnor.common.services.project.model.WorkspaceProject;
 import org.guvnor.common.services.shared.metadata.model.Metadata;
 import org.guvnor.common.services.shared.metadata.model.Overview;
 import org.guvnor.messageconsole.client.console.widget.button.AlertsButtonMenuItemBuilder;
 import org.jboss.errai.common.client.api.Caller;
+import org.jboss.errai.common.client.ui.ElementWrapperWidget;
 import org.jboss.errai.ioc.client.container.SyncBeanManager;
 import org.junit.Before;
 import org.junit.Rule;
 import org.junit.rules.ExpectedException;
+import org.kie.soup.commons.util.Maps;
 import org.kie.workbench.common.services.datamodel.model.PackageDataModelOracleBaselinePayload;
+import org.kie.workbench.common.services.shared.preferences.ApplicationPreferences;
 import org.kie.workbench.common.widgets.client.datamodel.AsyncPackageDataModelOracle;
 import org.kie.workbench.common.widgets.client.menu.FileMenuBuilder;
 import org.kie.workbench.common.widgets.client.menu.FileMenuBuilderImpl;
 import org.kie.workbench.common.widgets.client.popups.validation.ValidationPopup;
+import org.kie.workbench.common.widgets.client.search.common.EditorSearchIndex;
+import org.kie.workbench.common.widgets.client.search.component.SearchBarComponent;
 import org.kie.workbench.common.widgets.configresource.client.widget.bound.ImportsWidgetPresenter;
 import org.kie.workbench.common.widgets.metadata.client.KieMultipleDocumentEditorWrapperView;
 import org.kie.workbench.common.widgets.metadata.client.menu.RegisteredDocumentsMenuBuilder;
@@ -65,6 +77,7 @@ import org.uberfire.backend.vfs.Path;
 import org.uberfire.client.mvp.PerspectiveActivity;
 import org.uberfire.client.mvp.PerspectiveManager;
 import org.uberfire.client.mvp.PlaceManager;
+import org.uberfire.client.promise.Promises;
 import org.uberfire.client.workbench.events.ChangeTitleWidgetEvent;
 import org.uberfire.client.workbench.widgets.multipage.MultiPageEditor;
 import org.uberfire.ext.editor.commons.client.file.popups.CopyPopUpPresenter;
@@ -74,7 +87,7 @@ import org.uberfire.ext.editor.commons.client.file.popups.SavePopUpPresenter;
 import org.uberfire.ext.editor.commons.client.history.VersionRecordManager;
 import org.uberfire.ext.editor.commons.client.menu.BasicFileMenuBuilder;
 import org.uberfire.ext.editor.commons.client.menu.BasicFileMenuBuilderImpl;
-import org.uberfire.ext.editor.commons.client.menu.DownloadMenuItem;
+import org.uberfire.ext.editor.commons.client.menu.DownloadMenuItemBuilder;
 import org.uberfire.ext.editor.commons.client.menu.RestoreVersionCommandProvider;
 import org.uberfire.ext.editor.commons.client.validation.DefaultFileNameValidator;
 import org.uberfire.ext.editor.commons.version.VersionService;
@@ -85,10 +98,12 @@ import org.uberfire.mocks.CallerMock;
 import org.uberfire.mocks.EventSourceMock;
 import org.uberfire.mvp.Command;
 import org.uberfire.mvp.PlaceRequest;
+import org.uberfire.promise.SyncPromises;
 import org.uberfire.workbench.events.NotificationEvent;
 import org.uberfire.workbench.model.menu.MenuItem;
 
 import static org.junit.Assert.fail;
+import static org.kie.workbench.common.services.shared.preferences.ApplicationPreferences.DATE_FORMAT;
 import static org.mockito.Matchers.any;
 import static org.mockito.Mockito.doReturn;
 import static org.mockito.Mockito.eq;
@@ -218,7 +233,7 @@ public abstract class BaseGuidedDecisionTablePresenterTest<P extends BaseGuidedD
     protected BusyIndicatorView busyIndicatorView;
 
     @Mock
-    protected DownloadMenuItem downloadMenuItem;
+    protected DownloadMenuItemBuilder downloadMenuItemBuilder;
 
     @Mock
     protected MenuItem downloadMenuItemButton;
@@ -265,15 +280,49 @@ public abstract class BaseGuidedDecisionTablePresenterTest<P extends BaseGuidedD
     @Mock
     protected AlertsButtonMenuItemBuilder alertsButtonMenuItemBuilder;
 
+    @Mock
+    protected EditorSearchIndex<GuidedDecisionTableSearchableElement> editorSearchIndex;
+
+    @Mock
+    protected SearchBarComponent<GuidedDecisionTableSearchableElement> searchBarComponent;
+
+
     @Mock
     protected MenuItem alertsButtonMenuItem;
 
+    @Mock
+    protected Widget modellerViewWidget;
+
+    @Mock
+    protected Element modellerViewWidgetElement;
+
+    @Mock
+    protected SearchBarComponent.View searchBarView;
+
+    @Mock
+    protected HTMLElement searchBarViewHTMLElement;
+
+    @Mock
+    protected ElementWrapperWidget searchBarComponentWidget;
+
+    @Mock
+    private GuidedDecisionTableGridHighlightHelper highlightHelper;
+
+    protected Promises promises;
+
+    protected SearchableElementFactory searchableElementFactory;
+
     protected P presenter;
 
     @Before
     public void setup() {
+
+        ApplicationPreferences.setUp(new Maps.Builder<String, String>().put(DATE_FORMAT, "dd/mm/yy").build());
+
+        this.promises = new SyncPromises();
         this.dtServiceCaller = new CallerMock<>(dtService);
         this.versionServiceCaller = new CallerMock<>(versionService);
+        searchableElementFactory = new SearchableElementFactory(highlightHelper);
 
         final P wrapped = getPresenter();
 
@@ -304,12 +353,18 @@ public abstract class BaseGuidedDecisionTablePresenterTest<P extends BaseGuidedD
         when(presenter.getKieEditorWrapperMultiPage()).thenReturn(multiPageEditor);
 
         when(workbenchContext.getActiveOrganizationalUnit()).thenReturn(Optional.empty());
-        when(workbenchContext.getActiveWorkspaceProject()).thenReturn(Optional.empty());
-        when(downloadMenuItem.build(any())).thenReturn(downloadMenuItemButton);
+        when(workbenchContext.getActiveWorkspaceProject()).thenReturn(Optional.of(mock(WorkspaceProject.class)));
+        when(downloadMenuItemBuilder.build(any())).thenReturn(downloadMenuItemButton);
 
+        when(modellerView.asWidget()).thenReturn(modellerViewWidget);
+        when(modellerViewWidget.getElement()).thenReturn(modellerViewWidgetElement);
+        when(searchBarComponent.getView()).thenReturn(searchBarView);
+        when(searchBarView.getElement()).thenReturn(searchBarViewHTMLElement);
+
+        doReturn(searchBarComponentWidget).when(presenter).getWidget(searchBarViewHTMLElement);
         doReturn(alertsButtonMenuItem).when(alertsButtonMenuItemBuilder).build();
-
         doReturn(currentPerspective).when(perspectiveManager).getCurrentPerspective();
+        doReturn(promises.resolve(true)).when(projectController).canUpdateProject(any());
 
         presenter.init();
         presenter.setupMenuBar();
