@@ -21,6 +21,8 @@ import java.lang.reflect.Field;
 import java.util.Optional;
 import java.util.concurrent.atomic.AtomicInteger;
 
+import com.google.gwt.user.client.Element;
+import com.google.gwt.user.client.ui.Widget;
 import com.google.gwtmockito.GwtMockitoTestRunner;
 import org.drools.workbench.models.guided.dtable.shared.model.GuidedDecisionTable52;
 import org.drools.workbench.screens.guided.dtable.client.editor.clipboard.Clipboard;
@@ -30,6 +32,8 @@ import org.drools.workbench.screens.guided.dtable.client.editor.menu.RadarMenuBu
 import org.drools.workbench.screens.guided.dtable.client.editor.menu.RadarMenuView;
 import org.drools.workbench.screens.guided.dtable.client.editor.menu.ViewMenuBuilder;
 import org.drools.workbench.screens.guided.dtable.client.editor.page.ColumnsPage;
+import org.drools.workbench.screens.guided.dtable.client.editor.search.GuidedDecisionTableSearchableElement;
+import org.drools.workbench.screens.guided.dtable.client.editor.search.SearchableElementFactory;
 import org.drools.workbench.screens.guided.dtable.client.type.GuidedDTableResourceType;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.GuidedDecisionTableModellerView;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.events.cdi.DecisionTableSelectedEvent;
@@ -42,6 +46,7 @@ import org.guvnor.common.services.shared.metadata.model.Metadata;
 import org.guvnor.messageconsole.client.console.widget.button.AlertsButtonMenuItemBuilder;
 import org.jboss.errai.common.client.api.Caller;
 import org.jboss.errai.common.client.dom.HTMLElement;
+import org.jboss.errai.common.client.ui.ElementWrapperWidget;
 import org.jboss.errai.ioc.client.api.ManagedInstance;
 import org.jboss.errai.ioc.client.container.SyncBeanManager;
 import org.jboss.errai.ui.client.local.spi.TranslationService;
@@ -51,6 +56,8 @@ import org.junit.runner.RunWith;
 import org.kie.workbench.common.widgets.client.menu.FileMenuBuilder;
 import org.kie.workbench.common.widgets.client.menu.FileMenuBuilderImpl;
 import org.kie.workbench.common.widgets.client.popups.validation.ValidationPopup;
+import org.kie.workbench.common.widgets.client.search.common.EditorSearchIndex;
+import org.kie.workbench.common.widgets.client.search.component.SearchBarComponent;
 import org.kie.workbench.common.widgets.configresource.client.widget.bound.ImportsWidgetPresenter;
 import org.kie.workbench.common.widgets.metadata.client.KieMultipleDocumentEditorWrapperView;
 import org.kie.workbench.common.widgets.metadata.client.menu.RegisteredDocumentsMenuBuilder;
@@ -62,7 +69,9 @@ import org.mockito.Mock;
 import org.mockito.Spy;
 import org.uberfire.client.mvp.PerspectiveManager;
 import org.uberfire.client.mvp.PlaceManager;
+import org.uberfire.client.promise.Promises;
 import org.uberfire.client.workbench.events.ChangeTitleWidgetEvent;
+import org.uberfire.client.workbench.widgets.multipage.MultiPageEditor;
 import org.uberfire.ext.editor.commons.client.file.popups.CopyPopUpPresenter;
 import org.uberfire.ext.editor.commons.client.file.popups.DeletePopUpPresenter;
 import org.uberfire.ext.editor.commons.client.file.popups.RenamePopUpPresenter;
@@ -70,7 +79,7 @@ import org.uberfire.ext.editor.commons.client.file.popups.SavePopUpPresenter;
 import org.uberfire.ext.editor.commons.client.history.VersionRecordManager;
 import org.uberfire.ext.editor.commons.client.menu.BasicFileMenuBuilder;
 import org.uberfire.ext.editor.commons.client.menu.BasicFileMenuBuilderImpl;
-import org.uberfire.ext.editor.commons.client.menu.DownloadMenuItem;
+import org.uberfire.ext.editor.commons.client.menu.DownloadMenuItemBuilder;
 import org.uberfire.ext.editor.commons.client.menu.RestoreVersionCommandProvider;
 import org.uberfire.ext.editor.commons.client.menu.common.SaveAndRenameCommandBuilder;
 import org.uberfire.ext.editor.commons.client.validation.DefaultFileNameValidator;
@@ -88,6 +97,7 @@ import org.uberfire.ext.widgets.common.client.menu.MenuItemWithIconView;
 import org.uberfire.mocks.CallerMock;
 import org.uberfire.mocks.EventSourceMock;
 import org.uberfire.mvp.Command;
+import org.uberfire.promise.SyncPromises;
 import org.uberfire.workbench.events.NotificationEvent;
 import org.uberfire.workbench.model.menu.MenuCustom;
 import org.uberfire.workbench.model.menu.MenuGroup;
@@ -101,6 +111,7 @@ import org.uberfire.workbench.model.menu.Menus;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.fail;
 import static org.mockito.Matchers.any;
+import static org.mockito.Mockito.doReturn;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.spy;
 import static org.mockito.Mockito.when;
@@ -254,7 +265,7 @@ public class GuidedDecisionTableEditorMenusTest {
     protected AlertsButtonMenuItemBuilder alertsButtonMenuItemBuilder;
 
     @Mock
-    protected DownloadMenuItem downloadMenuItem;
+    protected DownloadMenuItemBuilder downloadMenuItem;
 
     @Mock
     protected MenuItem downloadMenuItemButton;
@@ -268,6 +279,35 @@ public class GuidedDecisionTableEditorMenusTest {
     @Mock
     protected PerspectiveManager perspectiveManager;
 
+    @Mock
+    protected SearchableElementFactory searchableElementFactory;
+
+    @Mock
+    protected EditorSearchIndex<GuidedDecisionTableSearchableElement> editorSearchIndex;
+
+    @Mock
+    protected SearchBarComponent<GuidedDecisionTableSearchableElement> searchBarComponent;
+
+    @Mock
+    protected Widget modellerViewWidget;
+
+    @Mock
+    protected Element modellerViewWidgetElement;
+
+    @Mock
+    protected elemental2.dom.HTMLElement searchBarViewHTMLElement;
+
+    @Mock
+    protected MultiPageEditor multiPageEditor;
+
+    @Mock
+    protected ElementWrapperWidget searchBarComponentWidget;
+
+    @Mock
+    protected SearchBarComponent.View searchBarView;
+
+    protected Promises promises;
+
     private GuidedDecisionTableEditorPresenter presenter;
     private GuidedDTableResourceType resourceType = new GuidedDTableResourceType(new Decision());
 
@@ -302,6 +342,7 @@ public class GuidedDecisionTableEditorMenusTest {
 
     @Before
     public void setup() {
+        promises = new SyncPromises();
         when(downloadMenuItem.build(any())).thenReturn(downloadMenuItemButton);
         when(alertsButtonMenuItemBuilder.build()).thenReturn(alertsButtonMenuItem);
         when(modeller.getView()).thenReturn(modellerView);
@@ -323,6 +364,10 @@ public class GuidedDecisionTableEditorMenusTest {
         when(menuItemViewDividerProducer.get()).thenReturn(mock(MenuItemDividerView.class));
         when(menuItemViewWithIconProducer.get()).thenReturn(menuItemWithIconView);
         when(menuItemWithIconView.getElement()).thenReturn(mock(HTMLElement.class));
+        when(modellerView.asWidget()).thenReturn(modellerViewWidget);
+        when(modellerViewWidget.getElement()).thenReturn(modellerViewWidgetElement);
+        when(searchBarComponent.getView()).thenReturn(searchBarView);
+        when(searchBarView.getElement()).thenReturn(searchBarViewHTMLElement);
 
         this.dtServiceCaller = new CallerMock<>(dtService);
         this.versionServiceCaller = new CallerMock<>(versionService);
@@ -362,7 +407,14 @@ public class GuidedDecisionTableEditorMenusTest {
                                                                                                   columnsPage,
                                                                                                   saveAndRenameCommandBuilder,
                                                                                                   alertsButtonMenuItemBuilder,
-                                                                                                  downloadMenuItem) {
+                                                                                                  downloadMenuItem,
+                                                                                                  editorSearchIndex,
+                                                                                                  searchBarComponent,
+                                                                                                  searchableElementFactory) {
+            {
+                promises = GuidedDecisionTableEditorMenusTest.this.promises;
+            }
+
             @Override
             protected Command getSaveAndRenameCommand() {
                 return mock(Command.class);
@@ -386,61 +438,65 @@ public class GuidedDecisionTableEditorMenusTest {
         when(workbenchContext.getActiveOrganizationalUnit()).thenReturn(Optional.empty());
         when(workbenchContext.getActiveWorkspaceProject()).thenReturn(Optional.empty());
 
+        doReturn(searchBarComponentWidget).when(presenter).getWidget(searchBarViewHTMLElement);
+        doReturn(multiPageEditor).when(presenter).getKieEditorWrapperMultiPage();
+
         presenter.init();
         presenter.setupMenuBar();
     }
 
     @Test
     public void checkMenuStructure() {
-        final AtomicInteger i = new AtomicInteger(0);
-        final Menus menus = presenter.getMenus();
-        final MenuVisitor visitor = new MenuVisitor() {
-            @Override
-            public boolean visitEnter(final Menus menus) {
-                return true;
-            }
+        presenter.getMenus(menus -> {
+            final AtomicInteger i = new AtomicInteger(0);
+            final MenuVisitor visitor = new MenuVisitor() {
+                @Override
+                public boolean visitEnter(final Menus menus) {
+                    return true;
+                }
 
-            @Override
-            public void visitLeave(final Menus menus) {
-            }
+                @Override
+                public void visitLeave(final Menus menus) {
+                }
 
-            @Override
-            public boolean visitEnter(final MenuGroup menuGroup) {
-                assertEquals(menuItemIdentifiers[i.getAndIncrement()],
-                             menuGroup.getIdentifier());
-                return true;
-            }
+                @Override
+                public boolean visitEnter(final MenuGroup menuGroup) {
+                    assertEquals(menuItemIdentifiers[i.getAndIncrement()],
+                                 menuGroup.getIdentifier());
+                    return true;
+                }
 
-            @Override
-            public void visitLeave(final MenuGroup menuGroup) {
+                @Override
+                public void visitLeave(final MenuGroup menuGroup) {
 
-            }
+                }
 
-            @Override
-            public void visit(final MenuItemPlain menuItemPlain) {
-                assertEquals(menuItemIdentifiers[i.getAndIncrement()],
-                             menuItemPlain.getIdentifier());
-            }
+                @Override
+                public void visit(final MenuItemPlain menuItemPlain) {
+                    assertEquals(menuItemIdentifiers[i.getAndIncrement()],
+                                 menuItemPlain.getIdentifier());
+                }
 
-            @Override
-            public void visit(final MenuItemCommand menuItemCommand) {
-                assertEquals(menuItemIdentifiers[i.getAndIncrement()],
-                             menuItemCommand.getIdentifier());
-            }
+                @Override
+                public void visit(final MenuItemCommand menuItemCommand) {
+                    assertEquals(menuItemIdentifiers[i.getAndIncrement()],
+                                 menuItemCommand.getIdentifier());
+                }
 
-            @Override
-            public void visit(final MenuItemPerspective menuItemPerspective) {
-                assertEquals(menuItemIdentifiers[i.getAndIncrement()],
-                             menuItemPerspective.getIdentifier());
-            }
+                @Override
+                public void visit(final MenuItemPerspective menuItemPerspective) {
+                    assertEquals(menuItemIdentifiers[i.getAndIncrement()],
+                                 menuItemPerspective.getIdentifier());
+                }
 
-            @Override
-            public void visit(final MenuCustom<?> menuCustom) {
-                assertEquals(menuItemIdentifiers[i.getAndIncrement()],
-                             menuCustom.getIdentifier());
-            }
-        };
-        menus.accept(visitor);
+                @Override
+                public void visit(final MenuCustom<?> menuCustom) {
+                    assertEquals(menuItemIdentifiers[i.getAndIncrement()],
+                                 menuCustom.getIdentifier());
+                }
+            };
+            menus.accept(visitor);
+        });
     }
 
     private RestoreVersionCommandProvider getRestoreVersionCommandProvider() {
