@@ -5,7 +5,7 @@
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- *       http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -16,18 +16,25 @@
 
 package org.drools.workbench.screens.guided.dtable.client.wizard.column.plugins;
 
+import java.util.Arrays;
+import java.util.Collections;
 import java.util.HashMap;
 import java.util.List;
+import java.util.Set;
 
 import com.google.gwtmockito.GwtMockitoTestRunner;
-import org.drools.workbench.models.datamodel.oracle.DataType;
 import org.drools.workbench.models.datamodel.rule.BaseSingleFieldConstraint;
+import org.drools.workbench.models.datamodel.rule.FactPattern;
+import org.drools.workbench.models.guided.dtable.shared.model.BRLConditionColumn;
+import org.drools.workbench.models.guided.dtable.shared.model.BRLRuleModel;
 import org.drools.workbench.models.guided.dtable.shared.model.ConditionCol52;
 import org.drools.workbench.models.guided.dtable.shared.model.DTCellValue52;
 import org.drools.workbench.models.guided.dtable.shared.model.GuidedDecisionTable52;
 import org.drools.workbench.models.guided.dtable.shared.model.Pattern52;
+import org.drools.workbench.models.guided.dtable.shared.model.adaptors.FactPatternPattern52Adaptor;
 import org.drools.workbench.screens.guided.dtable.client.resources.i18n.GuidedDecisionTableErraiConstants;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.GuidedDecisionTableView;
+import org.drools.workbench.screens.guided.dtable.client.widget.table.model.synchronizers.ModelSynchronizer.VetoUpdatePatternInUseException;
 import org.drools.workbench.screens.guided.dtable.client.wizard.column.NewGuidedDecisionTableColumnWizard;
 import org.drools.workbench.screens.guided.dtable.client.wizard.column.pages.AdditionalInfoPage;
 import org.drools.workbench.screens.guided.dtable.client.wizard.column.pages.CalculationTypePage;
@@ -40,6 +47,7 @@ import org.jboss.errai.ui.client.local.spi.TranslationService;
 import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
+import org.kie.soup.project.datamodel.oracle.DataType;
 import org.kie.workbench.common.widgets.client.datamodel.AsyncPackageDataModelOracle;
 import org.mockito.InOrder;
 import org.mockito.InjectMocks;
@@ -48,8 +56,22 @@ import org.uberfire.ext.widgets.core.client.wizards.WizardPage;
 import org.uberfire.ext.widgets.core.client.wizards.WizardPageStatusChangeEvent;
 import org.uberfire.mocks.EventSourceMock;
 
-import static org.junit.Assert.*;
-import static org.mockito.Mockito.*;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertNotSame;
+import static org.junit.Assert.assertNull;
+import static org.junit.Assert.assertTrue;
+import static org.mockito.Matchers.eq;
+import static org.mockito.Mockito.any;
+import static org.mockito.Mockito.anyString;
+import static org.mockito.Mockito.doReturn;
+import static org.mockito.Mockito.doThrow;
+import static org.mockito.Mockito.inOrder;
+import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.never;
+import static org.mockito.Mockito.spy;
+import static org.mockito.Mockito.verify;
+import static org.mockito.Mockito.when;
 
 @RunWith(GwtMockitoTestRunner.class)
 public class ConditionColumnPluginTest {
@@ -221,6 +243,37 @@ public class ConditionColumnPluginTest {
         verify(plugin).appendColumn();
     }
 
+    @Test
+    public void testGenerateColumnWhenColumnIsNotNewAndVetoed() throws Exception {
+        final ConditionCol52 originalColumn = mock(ConditionCol52.class);
+        final ConditionCol52 editingColumn = mock(ConditionCol52.class);
+        final Pattern52 originalPattern = mock(Pattern52.class);
+        final Pattern52 editingPattern = mock(Pattern52.class);
+
+        doReturn(false).when(plugin).isNewColumn();
+
+        doReturn(originalColumn).when(plugin).originalCondition();
+        doReturn(editingColumn).when(plugin).editingCol();
+        doReturn(originalPattern).when(plugin).getOriginalPattern52();
+        doReturn(editingPattern).when(plugin).editingPattern();
+
+        doReturn(false).when(plugin).isNewColumn();
+        doReturn(oracle).when(presenter).getDataModelOracle();
+        doReturn(false).when(oracle).hasEnums(any(),
+                                              any());
+
+        doThrow(VetoUpdatePatternInUseException.class).when(presenter).updateColumn(any(Pattern52.class),
+                                                                                    any(ConditionCol52.class),
+                                                                                    any(Pattern52.class),
+                                                                                    any(ConditionCol52.class));
+
+        plugin.setupDefaultValues();
+
+        assertFalse(plugin.generateColumn());
+
+        verify(wizard).showPatternInUseError();
+    }
+
     @Test
     public void testGetEditingPattern() throws Exception {
         final PatternWrapper patternWrapper = mock(PatternWrapper.class);
@@ -522,6 +575,22 @@ public class ConditionColumnPluginTest {
         assertTrue(plugin.isBindable());
     }
 
+    @Test
+    public void testIsBindableWhenTableIsAnExtendedEntryAndConstraintValueIsTypeFormula() {
+        doReturn(BaseSingleFieldConstraint.TYPE_RET_VALUE).when(plugin).constraintValue();
+        doReturn(GuidedDecisionTable52.TableFormat.EXTENDED_ENTRY).when(model).getTableFormat();
+
+        assertTrue(plugin.isBindable());
+    }
+
+    @Test
+    public void testIsBindableWhenTableIsAnExtendedEntryAndConstraintValueIsTypePredicate() {
+        doReturn(BaseSingleFieldConstraint.TYPE_PREDICATE).when(plugin).constraintValue();
+        doReturn(GuidedDecisionTable52.TableFormat.EXTENDED_ENTRY).when(model).getTableFormat();
+
+        assertFalse(plugin.isBindable());
+    }
+
     @Test
     public void testIsBindableWhenTableIsALimitedEntry() {
         doReturn(GuidedDecisionTable52.TableFormat.LIMITED_ENTRY).when(model).getTableFormat();
@@ -600,11 +669,6 @@ public class ConditionColumnPluginTest {
                       clone);
     }
 
-    @Test
-    public void testCloneWhenColumnIsALimitedEntryConditionCol52() {
-
-    }
-
     @Test
     public void testCloneWhenColumnIsAConditionCol52() {
         final int constraintValueType = BaseSingleFieldConstraint.TYPE_LITERAL;
@@ -699,6 +763,190 @@ public class ConditionColumnPluginTest {
         verify(editingCol).setHideColumn(hideColumn);
     }
 
+    @Test
+    public void testGetPatterns() throws Exception {
+        final Pattern52 pattern = new Pattern52() {{
+            setFactType("FactType");
+            setBoundName("$fact");
+        }};
+
+        doReturn(Collections.singletonList(pattern)).when(model).getConditions();
+        doReturn(pattern).when(model).getConditionPattern(eq("$fact"));
+
+        final Set<PatternWrapper> patterns = plugin.getPatterns();
+
+        assertEquals(1,
+                     patterns.size());
+        assertTrue(patterns.contains(new PatternWrapper("FactType",
+                                                        "$fact",
+                                                        false)));
+    }
+
+    @Test
+    public void testGetPatternsWithBRLCondition() throws Exception {
+        final Pattern52 pattern = new Pattern52() {{
+            setFactType("FactType");
+            setBoundName("$fact");
+        }};
+        final BRLConditionColumn brlColumn = new BRLConditionColumn();
+        final FactPattern fp = new FactPattern("AnotherFact") {{
+            setBoundName("$another");
+        }};
+        brlColumn.setDefinition(Collections.singletonList(fp));
+
+        doReturn(Arrays.asList(pattern,
+                               brlColumn)).when(model).getConditions();
+        doReturn(pattern).when(model).getConditionPattern(eq("$fact"));
+        doReturn(new FactPatternPattern52Adaptor(fp)).when(model).getConditionPattern(eq("$another"));
+
+        final Set<PatternWrapper> patterns = plugin.getPatterns();
+
+        assertEquals(1,
+                     patterns.size());
+        assertTrue(patterns.contains(new PatternWrapper("FactType",
+                                                        "$fact",
+                                                        false)));
+    }
+
+    @Test
+    public void testSetBinding() {
+        plugin.setBinding("$a");
+
+        verify(plugin).fireChangeEvent(eq(valueOptionsPage));
+    }
+
+    @Test
+    public void testIsFieldBindingValidWhenNotBindable() {
+        doReturn(false).when(plugin).isBindable();
+
+        assertTrue(plugin.isFieldBindingValid());
+    }
+
+    @Test
+    public void testIsFieldBindingValidWhenBindableNewColumnNoExistingBindings() {
+        doReturn(true).when(plugin).isBindable();
+        doReturn(true).when(plugin).isNewColumn();
+
+        assertTrue(plugin.isFieldBindingValid());
+    }
+
+    @Test
+    public void testIsFieldBindingValidWhenBindableNewColumnWithExistingBindingsNoClash() {
+        doReturn(true).when(plugin).isBindable();
+        doReturn(true).when(plugin).isNewColumn();
+        doReturn("$n").when(plugin).getBinding();
+
+        doReturn(Collections.singletonList(mockFactPattern("$a"))).when(model).getConditions();
+
+        assertTrue(plugin.isFieldBindingValid());
+    }
+
+    @Test
+    public void testIsFieldBindingValidWhenBindableNewColumnWithExistingBindingsWithClash() {
+        doReturn(true).when(plugin).isBindable();
+        doReturn(true).when(plugin).isNewColumn();
+        doReturn("$n").when(plugin).getBinding();
+
+        doReturn(Collections.singletonList(mockFactPattern("$n"))).when(model).getConditions();
+
+        assertFalse(plugin.isFieldBindingValid());
+    }
+
+    @Test
+    public void testIsFieldBindingValidWhenBindableEditColumnWithExistingBindingsNoClash() {
+        final ConditionCol52 originalColumn = mock(ConditionCol52.class);
+        doReturn(originalColumn).when(plugin).originalCondition();
+        doReturn(true).when(plugin).isBindable();
+        doReturn(false).when(plugin).isNewColumn();
+        doReturn("$n").when(plugin).getBinding();
+        doReturn("$n").when(originalColumn).getBinding();
+
+        assertTrue(plugin.isFieldBindingValid());
+    }
+
+    @Test
+    public void testIsFieldBindingValidWhenBindableEditColumnWithExistingBindingsWithClash() {
+        final ConditionCol52 originalColumn = mock(ConditionCol52.class);
+        doReturn(originalColumn).when(plugin).originalCondition();
+        doReturn(true).when(plugin).isBindable();
+        doReturn(false).when(plugin).isNewColumn();
+        doReturn("$a").when(plugin).getBinding();
+        doReturn("$n").when(originalColumn).getBinding();
+
+        doReturn(Collections.singletonList(mockFactPattern("$a"))).when(model).getConditions();
+
+        assertFalse(plugin.isFieldBindingValid());
+    }
+
+    @Test
+    public void testIsFieldBindingValidWhenNullBinding() {
+        doReturn(true).when(plugin).isBindable();
+        doReturn(null).when(plugin).getBinding();
+
+        assertTrue(plugin.isFieldBindingValid());
+    }
+
+    @Test
+    public void testIsFieldBindingValidWhenPluginBindingAndFactPatternBoundNameHaveTheSameValue() {
+
+        final PatternWrapper patternWrapper = mock(PatternWrapper.class);
+        final FactPattern factPattern = new FactPattern() {{
+            setBoundName("$fact");
+        }};
+
+        doReturn(BaseSingleFieldConstraint.TYPE_LITERAL).when(plugin).constraintValue();
+        doReturn(factPattern).when(patternWrapper).makeFactPattern();
+        doReturn(patternWrapper).when(plugin).patternWrapper();
+        doReturn("$fact").when(plugin).getBinding();
+
+        assertFalse(plugin.isFieldBindingValid());
+    }
+
+    @Test
+    public void testMakeBRLRuleModel() {
+
+        final String factType = "FactType";
+        final String boundName1 = "$fact1";
+        final String boundName2 = "$fact2";
+        final Pattern52 pattern = new Pattern52() {{
+            setFactType(factType);
+            setBoundName(boundName1);
+        }};
+        final FactPattern factPattern = new FactPattern() {{
+            setFactType(factType);
+            setBoundName(boundName2);
+        }};
+        final PatternWrapper patternWrapper = mock(PatternWrapper.class);
+
+        doReturn(factPattern).when(patternWrapper).makeFactPattern();
+        doReturn(patternWrapper).when(plugin).patternWrapper();
+        doReturn(Collections.singletonList(pattern)).when(model).getConditions();
+        doReturn(pattern).when(model).getConditionPattern(boundName1);
+
+        final BRLRuleModel brlRuleModel = plugin.makeBRLRuleModel();
+        final List<String> expectedVariables = Arrays.asList(boundName1, boundName2);
+        final List<String> actualVariables = brlRuleModel.getAllVariables();
+
+        assertEquals(expectedVariables, actualVariables);
+    }
+
+    @Test
+    public void testResetFieldAndOperator() {
+
+        plugin.resetFieldAndOperator();
+
+        verify(editingCol).setFactField("");
+        verify(editingCol).setBinding("");
+        verify(editingCol).setFieldType("");
+        verify(editingCol).setOperator("pleaseChoose");
+    }
+
+    private Pattern52 mockFactPattern(final String binding) {
+        final Pattern52 p = new Pattern52();
+        p.setBoundName(binding);
+        return p;
+    }
+
     private ConditionCol52 makeConditionCol52(final int constraintValueType,
                                               final String factField,
                                               final String fieldType,
