@@ -36,24 +36,27 @@ public class ListGroupItemPresenter implements ListGroupItemView.Presenter {
     @Inject
     protected FieldItemPresenter fieldItemPresenter;
 
-    protected RightPanelView.Presenter rightPanelPresenter;
+    protected TestToolsView.Presenter testToolsPresenter;
 
     protected Map<String, ListGroupItemView> listGroupItemViewMap = new HashMap<>();
 
     private AtomicBoolean disabled = new AtomicBoolean(true);
 
-    private String factName = null;
+    /* In case of a selected column with <b>assigned</b> Instance, it contains its related Instance title.
+       Otherwise, in case of a <b>NOT assigned</b> Instance, it contains all the titles assigned to other columns of
+       the same group with the following syntax: "TITLE1;TITLE2;.." */
+    private String filterTerm = null;
 
     @Override
     public void enable() {
         this.disabled.set(false);
-        factName = null;
+        filterTerm = null;
     }
 
     @Override
-    public void enable(String factName) {
+    public void enable(String filterTerm) {
         this.disabled.set(false);
-        this.factName = factName;
+        this.filterTerm = filterTerm;
     }
 
     @Override
@@ -95,18 +98,28 @@ public class ListGroupItemPresenter implements ListGroupItemView.Presenter {
         }
     }
 
+    @Override
+    public boolean isInstanceAssigned(String factName) {
+        return listGroupItemViewMap.get(factName).isInstanceAssigned();
+    }
+
+    @Override
+    public void setInstanceAssigned(String factName, boolean assigned) {
+        listGroupItemViewMap.get(factName).setInstanceAssigned(assigned);
+    }
+
     @Override
     public void disable() {
         this.disabled.set(true);
-        factName = null;
+        filterTerm = null;
         listGroupItemViewMap.values().forEach(ListGroupItemView::closeRow);
         unselectAll();
         fieldItemPresenter.unselectAll();
     }
 
     @Override
-    public void init(RightPanelView.Presenter rightPanelPresenter) {
-        this.rightPanelPresenter = rightPanelPresenter;
+    public void init(TestToolsView.Presenter testToolsPresenter) {
+        this.testToolsPresenter = testToolsPresenter;
         fieldItemPresenter.setListGroupItemPresenter(this);
     }
 
@@ -134,8 +147,8 @@ public class ListGroupItemPresenter implements ListGroupItemView.Presenter {
         } else {
             if (listGroupItemView.isToExpand()) {
                 FactModelTree factModelTree =
-                        rightPanelPresenter.getFactModelTreeFromFactTypeMap(listGroupItemView.getFactType())
-                                .orElseGet(() -> rightPanelPresenter.getFactModelTreeFromHiddenMap(listGroupItemView.getFactType()));
+                        testToolsPresenter.getFactModelTreeFromFactTypeMap(listGroupItemView.getFactType())
+                                .orElseGet(() -> testToolsPresenter.getFactModelTreeFromHiddenMap(listGroupItemView.getFactType()));
                 if (factModelTree != null) {
                     populateListGroupItemView(listGroupItemView, listGroupItemView.getParentPath(), listGroupItemView.getFactName(), factModelTree);
                     listGroupItemView.setToExpand(false);
@@ -147,17 +160,28 @@ public class ListGroupItemPresenter implements ListGroupItemView.Presenter {
 
     @Override
     public void onSelectedElement(ListGroupItemView selected) {
-        rightPanelPresenter.setSelectedElement(selected);
+        testToolsPresenter.setSelectedElement(selected);
         listGroupItemViewMap.values().stream().filter(listGroupItemView -> !listGroupItemView.equals(selected)).forEach(ListGroupItemView::unselect);
         fieldItemPresenter.unselectAll();
     }
 
     @Override
     public void onSelectedElement(FieldItemView selected) {
-        rightPanelPresenter.setSelectedElement(selected);
+        testToolsPresenter.setSelectedElement(selected);
         listGroupItemViewMap.values().forEach(ListGroupItemView::unselect);
     }
 
+    @Override
+    public void reset() {
+        fieldItemPresenter.reset();
+        listGroupItemViewMap.clear();
+    }
+
+    @Override
+    public String getFilterTerm() {
+        return filterTerm;
+    }
+
     /**
      * Populate the "Assets" list. When
      * @param toPopulate
